@@ -12,8 +12,8 @@
 #'   generate dynamic functions that map to each tool. Used to save time if you
 #'   only want to import a single library.
 #' @param raster_backend A character vector to specify the library to use for
-#'   handling raster data. Currently, either "raster", "terra" or "stars" is
-#'   supported. The default is "raster".
+#'   handling raster data. Currently, either "terra" or "stars" is
+#'   supported. The default is "terra".
 #' @param vector_backend A character to specify the library to use for handling
 #'   vector data. Currently, either "sf", "SpatVector" or "SpatVectorProxy" is
 #'   supported. The default is "sf".
@@ -23,10 +23,10 @@
 saga_env <-
   function(saga_bin = NULL,
            opt_lib = NULL,
-           raster_backend = "raster",
+           raster_backend = "terra",
            vector_backend = "sf") {
-    if (!raster_backend %in% c("raster", "terra", "stars")) {
-      rlang::abort("The `raster_backend` must be one of 'raster', 'terra' or 'stars'")
+    if (!raster_backend %in% c("terra", "stars")) {
+      rlang::abort("The `raster_backend` must be one of 'terra' or 'stars'")
     }
     
     if (!vector_backend %in% c("sf", "SpatVector", "SpatVectorProxy")) {
@@ -123,8 +123,10 @@ saga_env <-
                 description = description,
                 html_file = tool
               )
-              
-              libraries[[basename(libdir)]][[tool_config$tool_name]] <- tool_config
+              lib_name <- basename(libdir)
+              lib_name <- tolower(lib_name)
+              lib_name <- gsub(" ", "_", lib_name)
+              libraries[[lib_name]][[tool_config$tool_name]] <- tool_config
             }
             
           },
@@ -345,13 +347,9 @@ saga_configure <-
 #' @param cores An integer for the maximum number of processing cores. By
 #'   default all cores are utilized. Needs to be set to 1 if file caching is
 #'   activated.
-#' @param backend A character vector to specify the library to use for handling
-#'   raster data. Currently, "raster", "terra" or "stars" is supported. The
-#'   default is "raster". Will be deprecated in the future in favour of
-#'   `raster_backend`.
 #' @param raster_backend A character vector to specify the library to use for
-#'   handling raster data. Currently, "raster", "terra" or "stars" is supported.
-#'   The default is "raster".
+#'   handling raster data. Supported options are "terra" or "stars".
+#'   The default is "terra".
 #' @param vector_backend A character to specify the library to use for handling
 #'   vector data. Currently, "sf", "SpatVector" or "SpatVectorProxy" is
 #'   supported. The default is "sf", however for large vector datasets, using
@@ -376,7 +374,7 @@ saga_configure <-
 #' @param intern A logical to indicate whether to load the SAGA-GIS
 #'   geoprocessing results as an R object, default = TRUE. For instance, if a
 #'   raster grid is output by SAGA-GIS then this will be loaded as either as
-#'   `RasterLayer` or `SpatRaster` object, depending on the `raster_backend`
+#'   a `SpatRaster` or `stars` object, depending on the `raster_backend`
 #'   setting that is used. Vector data sets are always loaded as `sf` objects,
 #'   and tabular data sets are loaded as tibbles. The `intern` settings for the
 #'   `saga` object can be overridden for individual tools using the `.intern`
@@ -396,12 +394,11 @@ saga_configure <-
 #'   libraries and tools.
 #'
 #' @export
-#' @import raster
 #' @examples
 #' \dontrun{
 #' # Initialize a saga object
 #' library(Rsagacmd)
-#' library(raster)
+#' library(terra)
 #'
 #' saga <- saga_gis()
 #'
@@ -432,8 +429,7 @@ saga_gis <-
            grid_cache_threshold = 100,
            grid_cache_dir = NULL,
            cores = NULL,
-           backend = "raster",
-           raster_backend = "raster",
+           raster_backend = "terra",
            vector_backend = "sf",
            raster_format = "SAGA",
            vector_format = c("ESRI Shapefile", "GeoPackage"),
@@ -442,11 +438,7 @@ saga_gis <-
            opt_lib = NULL,
            temp_path = NULL,
            verbose = FALSE) {
-    if (!missing(backend)) {
-      .Deprecated(new = "raster_backend", old = "backend")
-      raster_backend <- backend
-    }
-    
+
     senv <- saga_env(saga_bin, opt_lib, raster_backend, vector_backend)
     senv$verbose <- verbose
     senv$all_outputs <- all_outputs
